{# Empty state: icon, message, hint #}
<div class="text-center py-8">
    <i data-lucide="{{ icon }}" class="w-10 h-10 text-zinc-300 mx-auto"></i>
    <p class="text-sm text-zinc-400 mt-2">{{ message }}</p>
    {% if hint %}
    <p class="text-xs text-zinc-400 mt-1">{{ hint }}</p>
    {% endif %}
</div>
